@@ -3,7 +3,7 @@ __author__ = 'Vlad Romanenko'
 
 
 from abc import ABC, abstractmethod
-from zmeiapi.io.Logger import logger
+from zmeiapi.zmei_io.Logger import logger
 
 
 class MaterialCreator(ABC):
